Module segments

Module segments 

Segment sources, caches, and sinks used by file readers and writers.

Structs

FileSegmentSource
A SegmentSource for file-like IO.
InitialReadSegmentCache
Segment cache containing the initial read segments.
RequestMetrics
Metrics emitted by the file segment request driver.

Enums

ReadEvent
Events sent from segment futures to the coalescing read driver.