pub struct VortexFile { /* private fields */ }Expand description
Represents a Vortex file, providing access to its metadata and content.
A VortexFile is created by opening a Vortex file using VortexOpenOptions.
It provides methods for accessing file metadata (such as row count, data type, and statistics)
and for initiating scans to read the file’s contents.
Implementations
Sourceimpl VortexFile
impl VortexFile
Sourcepub fn new(
footer: Footer,
segment_source: Arc<dyn SegmentSource>,
session: VortexSession,
) -> Self
pub fn new( footer: Footer, segment_source: Arc<dyn SegmentSource>, session: VortexSession, ) -> Self
Creates a new VortexFile from the given footer, segment source, and session.
Sourcepub fn with_caching(self) -> Self
pub fn with_caching(self) -> Self
Enable layout reader caching.
Repeated calls to layout_reader, scan, and
data_source will share the same reader tree.
Returns a reference to the file’s footer, which contains metadata and layout information.
Sourcepub fn file_stats(&self) -> Option<&FileStatistics>
pub fn file_stats(&self) -> Option<&FileStatistics>
Returns the file’s statistics, if available.
Statistics can be used for query optimization and data exploration.
Sourcepub fn segment_source(&self) -> Arc<dyn SegmentSource>
pub fn segment_source(&self) -> Arc<dyn SegmentSource>
Create a new segment source for reading from the file.
This may spawn a background I/O driver that will exit when the returned segment source is dropped.
Sourcepub fn session(&self) -> &VortexSession
pub fn session(&self) -> &VortexSession
Returns a reference to the Vortex session used to open this file.
Sourcepub fn layout_reader(&self) -> VortexResult<Arc<dyn LayoutReader>>
pub fn layout_reader(&self) -> VortexResult<Arc<dyn LayoutReader>>
Create a new layout reader for the file.
Wraps the root layout in a FileStatsLayoutReader if file stats are available.
Sourcepub fn data_source(&self) -> VortexResult<DataSourceRef>
pub fn data_source(&self) -> VortexResult<DataSourceRef>
Create a DataSource from this file for scanning.
Wraps the file’s layout reader with FileStatsLayoutReader (when file-level
statistics are available) and LayoutReaderDataSource.
Sourcepub fn scan(&self) -> VortexResult<ScanBuilder<ArrayRef>>
pub fn scan(&self) -> VortexResult<ScanBuilder<ArrayRef>>
Initiate a scan of the file, returning a builder for projection, filtering, selection, and execution options.
Sourcepub fn can_prune(&self, filter: &Expression) -> VortexResult<bool>
pub fn can_prune(&self, filter: &Expression) -> VortexResult<bool>
Returns true if file-level statistics prove the expression cannot
match any rows in this file.
Row-count-aware pruning predicates are evaluated with the file’s total row count as their scope.
Sourcepub fn splits(&self) -> VortexResult<Vec<Range<u64>>>
pub fn splits(&self) -> VortexResult<Vec<Range<u64>>>
Return the file’s natural row splits as root-coordinate ranges.
These are the ranges that SplitBy::Layout would use for an all-fields scan.