pub async fn open_cached(
session: &VortexSession,
key: Option<&str>,
source: Arc<dyn VortexReadAt>,
file_size: Option<u64>,
open_options_fn: &(dyn Fn(VortexOpenOptions) -> VortexOpenOptions + Send + Sync),
) -> VortexResult<VortexFile>Expand description
Open a Vortex file and cache its footer on the session. Subsequent calls to this function will reuse the footer from cache.
“key” is the optional cache key provided by user. If it’s not found, source.uri() is probed. If there’s no uri(), open_cached errors.